# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/cjm-fasthtml-virtual-collection',
                'doc_host': 'https://cj-mills.github.io',
                'git_url': 'https://github.com/cj-mills/cjm-fasthtml-virtual-collection',
                'lib_path': 'cjm_fasthtml_virtual_collection'},
  'syms': { 'cjm_fasthtml_virtual_collection.components.collection': { 'cjm_fasthtml_virtual_collection.components.collection.render_virtual_collection': ( 'components/collection.html#render_virtual_collection',
                                                                                                                                                            'cjm_fasthtml_virtual_collection/components/collection.py')},
            'cjm_fasthtml_virtual_collection.components.footer': { 'cjm_fasthtml_virtual_collection.components.footer.render_footer': ( 'components/footer.html#render_footer',
                                                                                                                                        'cjm_fasthtml_virtual_collection/components/footer.py')},
            'cjm_fasthtml_virtual_collection.components.scrollbar': { 'cjm_fasthtml_virtual_collection.components.scrollbar._map_to_scrollbar': ( 'components/scrollbar.html#_map_to_scrollbar',
                                                                                                                                                  'cjm_fasthtml_virtual_collection/components/scrollbar.py'),
                                                                      'cjm_fasthtml_virtual_collection.components.scrollbar.render_scrollbar': ( 'components/scrollbar.html#render_scrollbar',
                                                                                                                                                 'cjm_fasthtml_virtual_collection/components/scrollbar.py'),
                                                                      'cjm_fasthtml_virtual_collection.components.scrollbar.render_scrollbar_thumb': ( 'components/scrollbar.html#render_scrollbar_thumb',
                                                                                                                                                       'cjm_fasthtml_virtual_collection/components/scrollbar.py')},
            'cjm_fasthtml_virtual_collection.components.table': { 'cjm_fasthtml_virtual_collection.components.table._sort_indicator': ( 'components/table.html#_sort_indicator',
                                                                                                                                        'cjm_fasthtml_virtual_collection/components/table.py'),
                                                                  'cjm_fasthtml_virtual_collection.components.table.render_cell_oob': ( 'components/table.html#render_cell_oob',
                                                                                                                                        'cjm_fasthtml_virtual_collection/components/table.py'),
                                                                  'cjm_fasthtml_virtual_collection.components.table.render_data_cell': ( 'components/table.html#render_data_cell',
                                                                                                                                         'cjm_fasthtml_virtual_collection/components/table.py'),
                                                                  'cjm_fasthtml_virtual_collection.components.table.render_data_row': ( 'components/table.html#render_data_row',
                                                                                                                                        'cjm_fasthtml_virtual_collection/components/table.py'),
                                                                  'cjm_fasthtml_virtual_collection.components.table.render_header_cell': ( 'components/table.html#render_header_cell',
                                                                                                                                           'cjm_fasthtml_virtual_collection/components/table.py'),
                                                                  'cjm_fasthtml_virtual_collection.components.table.render_header_row': ( 'components/table.html#render_header_row',
                                                                                                                                          'cjm_fasthtml_virtual_collection/components/table.py'),
                                                                  'cjm_fasthtml_virtual_collection.components.table.render_row_oob': ( 'components/table.html#render_row_oob',
                                                                                                                                       'cjm_fasthtml_virtual_collection/components/table.py'),
                                                                  'cjm_fasthtml_virtual_collection.components.table.render_slot': ( 'components/table.html#render_slot',
                                                                                                                                    'cjm_fasthtml_virtual_collection/components/table.py'),
                                                                  'cjm_fasthtml_virtual_collection.components.table.render_table_rows': ( 'components/table.html#render_table_rows',
                                                                                                                                          'cjm_fasthtml_virtual_collection/components/table.py'),
                                                                  'cjm_fasthtml_virtual_collection.components.table.render_visible_cells_oob': ( 'components/table.html#render_visible_cells_oob',
                                                                                                                                                 'cjm_fasthtml_virtual_collection/components/table.py')},
            'cjm_fasthtml_virtual_collection.core.button_ids': { 'cjm_fasthtml_virtual_collection.core.button_ids.VirtualCollectionButtonIds': ( 'core/button_ids.html#virtualcollectionbuttonids',
                                                                                                                                                 'cjm_fasthtml_virtual_collection/core/button_ids.py'),
                                                                 'cjm_fasthtml_virtual_collection.core.button_ids.VirtualCollectionButtonIds.activate': ( 'core/button_ids.html#virtualcollectionbuttonids.activate',
                                                                                                                                                          'cjm_fasthtml_virtual_collection/core/button_ids.py'),
                                                                 'cjm_fasthtml_virtual_collection.core.button_ids.VirtualCollectionButtonIds.nav_down': ( 'core/button_ids.html#virtualcollectionbuttonids.nav_down',
                                                                                                                                                          'cjm_fasthtml_virtual_collection/core/button_ids.py'),
                                                                 'cjm_fasthtml_virtual_collection.core.button_ids.VirtualCollectionButtonIds.nav_first': ( 'core/button_ids.html#virtualcollectionbuttonids.nav_first',
                                                                                                                                                           'cjm_fasthtml_virtual_collection/core/button_ids.py'),
                                                                 'cjm_fasthtml_virtual_collection.core.button_ids.VirtualCollectionButtonIds.nav_last': ( 'core/button_ids.html#virtualcollectionbuttonids.nav_last',
                                                                                                                                                          'cjm_fasthtml_virtual_collection/core/button_ids.py'),
                                                                 'cjm_fasthtml_virtual_collection.core.button_ids.VirtualCollectionButtonIds.nav_page_down': ( 'core/button_ids.html#virtualcollectionbuttonids.nav_page_down',
                                                                                                                                                               'cjm_fasthtml_virtual_collection/core/button_ids.py'),
                                                                 'cjm_fasthtml_virtual_collection.core.button_ids.VirtualCollectionButtonIds.nav_page_up': ( 'core/button_ids.html#virtualcollectionbuttonids.nav_page_up',
                                                                                                                                                             'cjm_fasthtml_virtual_collection/core/button_ids.py'),
                                                                 'cjm_fasthtml_virtual_collection.core.button_ids.VirtualCollectionButtonIds.nav_up': ( 'core/button_ids.html#virtualcollectionbuttonids.nav_up',
                                                                                                                                                        'cjm_fasthtml_virtual_collection/core/button_ids.py')},
            'cjm_fasthtml_virtual_collection.core.html_ids': { 'cjm_fasthtml_virtual_collection.core.html_ids.VirtualCollectionHtmlIds': ( 'core/html_ids.html#virtualcollectionhtmlids',
                                                                                                                                           'cjm_fasthtml_virtual_collection/core/html_ids.py'),
                                                               'cjm_fasthtml_virtual_collection.core.html_ids.VirtualCollectionHtmlIds.cell_id': ( 'core/html_ids.html#virtualcollectionhtmlids.cell_id',
                                                                                                                                                   'cjm_fasthtml_virtual_collection/core/html_ids.py'),
                                                               'cjm_fasthtml_virtual_collection.core.html_ids.VirtualCollectionHtmlIds.collection': ( 'core/html_ids.html#virtualcollectionhtmlids.collection',
                                                                                                                                                      'cjm_fasthtml_virtual_collection/core/html_ids.py'),
                                                               'cjm_fasthtml_virtual_collection.core.html_ids.VirtualCollectionHtmlIds.footer': ( 'core/html_ids.html#virtualcollectionhtmlids.footer',
                                                                                                                                                  'cjm_fasthtml_virtual_collection/core/html_ids.py'),
                                                               'cjm_fasthtml_virtual_collection.core.html_ids.VirtualCollectionHtmlIds.header': ( 'core/html_ids.html#virtualcollectionhtmlids.header',
                                                                                                                                                  'cjm_fasthtml_virtual_collection/core/html_ids.py'),
                                                               'cjm_fasthtml_virtual_collection.core.html_ids.VirtualCollectionHtmlIds.item_id': ( 'core/html_ids.html#virtualcollectionhtmlids.item_id',
                                                                                                                                                   'cjm_fasthtml_virtual_collection/core/html_ids.py'),
                                                               'cjm_fasthtml_virtual_collection.core.html_ids.VirtualCollectionHtmlIds.progress': ( 'core/html_ids.html#virtualcollectionhtmlids.progress',
                                                                                                                                                    'cjm_fasthtml_virtual_collection/core/html_ids.py'),
                                                               'cjm_fasthtml_virtual_collection.core.html_ids.VirtualCollectionHtmlIds.refit_trigger': ( 'core/html_ids.html#virtualcollectionhtmlids.refit_trigger',
                                                                                                                                                         'cjm_fasthtml_virtual_collection/core/html_ids.py'),
                                                               'cjm_fasthtml_virtual_collection.core.html_ids.VirtualCollectionHtmlIds.row_id': ( 'core/html_ids.html#virtualcollectionhtmlids.row_id',
                                                                                                                                                  'cjm_fasthtml_virtual_collection/core/html_ids.py'),
                                                               'cjm_fasthtml_virtual_collection.core.html_ids.VirtualCollectionHtmlIds.rows': ( 'core/html_ids.html#virtualcollectionhtmlids.rows',
                                                                                                                                                'cjm_fasthtml_virtual_collection/core/html_ids.py'),
                                                               'cjm_fasthtml_virtual_collection.core.html_ids.VirtualCollectionHtmlIds.scrollbar_thumb': ( 'core/html_ids.html#virtualcollectionhtmlids.scrollbar_thumb',
                                                                                                                                                           'cjm_fasthtml_virtual_collection/core/html_ids.py'),
                                                               'cjm_fasthtml_virtual_collection.core.html_ids.VirtualCollectionHtmlIds.scrollbar_track': ( 'core/html_ids.html#virtualcollectionhtmlids.scrollbar_track',
                                                                                                                                                           'cjm_fasthtml_virtual_collection/core/html_ids.py'),
                                                               'cjm_fasthtml_virtual_collection.core.html_ids.VirtualCollectionHtmlIds.slot_id': ( 'core/html_ids.html#virtualcollectionhtmlids.slot_id',
                                                                                                                                                   'cjm_fasthtml_virtual_collection/core/html_ids.py'),
                                                               'cjm_fasthtml_virtual_collection.core.html_ids.VirtualCollectionHtmlIds.table': ( 'core/html_ids.html#virtualcollectionhtmlids.table',
                                                                                                                                                 'cjm_fasthtml_virtual_collection/core/html_ids.py'),
                                                               'cjm_fasthtml_virtual_collection.core.html_ids.VirtualCollectionHtmlIds.viewport': ( 'core/html_ids.html#virtualcollectionhtmlids.viewport',
                                                                                                                                                    'cjm_fasthtml_virtual_collection/core/html_ids.py'),
                                                               'cjm_fasthtml_virtual_collection.core.html_ids.VirtualCollectionHtmlIds.window_start_input': ( 'core/html_ids.html#virtualcollectionhtmlids.window_start_input',
                                                                                                                                                              'cjm_fasthtml_virtual_collection/core/html_ids.py'),
                                                               'cjm_fasthtml_virtual_collection.core.html_ids.VirtualCollectionHtmlIds.wrapper': ( 'core/html_ids.html#virtualcollectionhtmlids.wrapper',
                                                                                                                                                   'cjm_fasthtml_virtual_collection/core/html_ids.py')},
            'cjm_fasthtml_virtual_collection.core.models': { 'cjm_fasthtml_virtual_collection.core.models.CellRenderContext': ( 'core/models.html#cellrendercontext',
                                                                                                                                'cjm_fasthtml_virtual_collection/core/models.py'),
                                                             'cjm_fasthtml_virtual_collection.core.models.ColumnDef': ( 'core/models.html#columndef',
                                                                                                                        'cjm_fasthtml_virtual_collection/core/models.py'),
                                                             'cjm_fasthtml_virtual_collection.core.models.RowRenderContext': ( 'core/models.html#rowrendercontext',
                                                                                                                               'cjm_fasthtml_virtual_collection/core/models.py'),
                                                             'cjm_fasthtml_virtual_collection.core.models.VirtualCollectionConfig': ( 'core/models.html#virtualcollectionconfig',
                                                                                                                                      'cjm_fasthtml_virtual_collection/core/models.py'),
                                                             'cjm_fasthtml_virtual_collection.core.models.VirtualCollectionConfig.__post_init__': ( 'core/models.html#virtualcollectionconfig.__post_init__',
                                                                                                                                                    'cjm_fasthtml_virtual_collection/core/models.py'),
                                                             'cjm_fasthtml_virtual_collection.core.models.VirtualCollectionState': ( 'core/models.html#virtualcollectionstate',
                                                                                                                                     'cjm_fasthtml_virtual_collection/core/models.py'),
                                                             'cjm_fasthtml_virtual_collection.core.models.VirtualCollectionUrls': ( 'core/models.html#virtualcollectionurls',
                                                                                                                                    'cjm_fasthtml_virtual_collection/core/models.py'),
                                                             'cjm_fasthtml_virtual_collection.core.models._auto_prefix': ( 'core/models.html#_auto_prefix',
                                                                                                                           'cjm_fasthtml_virtual_collection/core/models.py')},
            'cjm_fasthtml_virtual_collection.core.windowing': { 'cjm_fasthtml_virtual_collection.core.windowing.clamp_window_start': ( 'core/windowing.html#clamp_window_start',
                                                                                                                                       'cjm_fasthtml_virtual_collection/core/windowing.py'),
                                                                'cjm_fasthtml_virtual_collection.core.windowing.compute_window': ( 'core/windowing.html#compute_window',
                                                                                                                                   'cjm_fasthtml_virtual_collection/core/windowing.py'),
                                                                'cjm_fasthtml_virtual_collection.core.windowing.find_nearest_focusable': ( 'core/windowing.html#find_nearest_focusable',
                                                                                                                                           'cjm_fasthtml_virtual_collection/core/windowing.py'),
                                                                'cjm_fasthtml_virtual_collection.core.windowing.navigate': ( 'core/windowing.html#navigate',
                                                                                                                             'cjm_fasthtml_virtual_collection/core/windowing.py'),
                                                                'cjm_fasthtml_virtual_collection.core.windowing.navigate_cursor': ( 'core/windowing.html#navigate_cursor',
                                                                                                                                    'cjm_fasthtml_virtual_collection/core/windowing.py')},
            'cjm_fasthtml_virtual_collection.js.auto_fit': {},
            'cjm_fasthtml_virtual_collection.js.scroll': { 'cjm_fasthtml_virtual_collection.js.scroll.generate_scroll_nav_js': ( 'js/scroll.html#generate_scroll_nav_js',
                                                                                                                                 'cjm_fasthtml_virtual_collection/js/scroll.py')},
            'cjm_fasthtml_virtual_collection.js.scrollbar': { 'cjm_fasthtml_virtual_collection.js.scrollbar.generate_scrollbar_js': ( 'js/scrollbar.html#generate_scrollbar_js',
                                                                                                                                      'cjm_fasthtml_virtual_collection/js/scrollbar.py')},
            'cjm_fasthtml_virtual_collection.js.touch': { 'cjm_fasthtml_virtual_collection.js.touch.generate_touch_nav_js': ( 'js/touch.html#generate_touch_nav_js',
                                                                                                                              'cjm_fasthtml_virtual_collection/js/touch.py')},
            'cjm_fasthtml_virtual_collection.keyboard.actions': { 'cjm_fasthtml_virtual_collection.keyboard.actions.apply_nav_sync': ( 'keyboard/actions.html#apply_nav_sync',
                                                                                                                                       'cjm_fasthtml_virtual_collection/keyboard/actions.py'),
                                                                  'cjm_fasthtml_virtual_collection.keyboard.actions.build_collection_url_map': ( 'keyboard/actions.html#build_collection_url_map',
                                                                                                                                                 'cjm_fasthtml_virtual_collection/keyboard/actions.py'),
                                                                  'cjm_fasthtml_virtual_collection.keyboard.actions.create_collection_focus_zone': ( 'keyboard/actions.html#create_collection_focus_zone',
                                                                                                                                                     'cjm_fasthtml_virtual_collection/keyboard/actions.py'),
                                                                  'cjm_fasthtml_virtual_collection.keyboard.actions.create_collection_nav_actions': ( 'keyboard/actions.html#create_collection_nav_actions',
                                                                                                                                                      'cjm_fasthtml_virtual_collection/keyboard/actions.py')},
            'cjm_fasthtml_virtual_collection.routes.handlers': { 'cjm_fasthtml_virtual_collection.routes.handlers._append_cursor_change': ( 'routes/handlers.html#_append_cursor_change',
                                                                                                                                            'cjm_fasthtml_virtual_collection/routes/handlers.py'),
                                                                 'cjm_fasthtml_virtual_collection.routes.handlers._build_container_response': ( 'routes/handlers.html#_build_container_response',
                                                                                                                                                'cjm_fasthtml_virtual_collection/routes/handlers.py'),
                                                                 'cjm_fasthtml_virtual_collection.routes.handlers._call_action_callback': ( 'routes/handlers.html#_call_action_callback',
                                                                                                                                            'cjm_fasthtml_virtual_collection/routes/handlers.py'),
                                                                 'cjm_fasthtml_virtual_collection.routes.handlers._is_cursor_visible': ( 'routes/handlers.html#_is_cursor_visible',
                                                                                                                                         'cjm_fasthtml_virtual_collection/routes/handlers.py'),
                                                                 'cjm_fasthtml_virtual_collection.routes.handlers._render_scrollbar_nav_oob': ( 'routes/handlers.html#_render_scrollbar_nav_oob',
                                                                                                                                                'cjm_fasthtml_virtual_collection/routes/handlers.py'),
                                                                 'cjm_fasthtml_virtual_collection.routes.handlers._render_scrollbar_oob': ( 'routes/handlers.html#_render_scrollbar_oob',
                                                                                                                                            'cjm_fasthtml_virtual_collection/routes/handlers.py'),
                                                                 'cjm_fasthtml_virtual_collection.routes.handlers._render_window_start_oob': ( 'routes/handlers.html#_render_window_start_oob',
                                                                                                                                               'cjm_fasthtml_virtual_collection/routes/handlers.py'),
                                                                 'cjm_fasthtml_virtual_collection.routes.handlers._scroll_to_cursor': ( 'routes/handlers.html#_scroll_to_cursor',
                                                                                                                                        'cjm_fasthtml_virtual_collection/routes/handlers.py'),
                                                                 'cjm_fasthtml_virtual_collection.routes.handlers.build_cursor_move_response': ( 'routes/handlers.html#build_cursor_move_response',
                                                                                                                                                 'cjm_fasthtml_virtual_collection/routes/handlers.py'),
                                                                 'cjm_fasthtml_virtual_collection.routes.handlers.build_items_changed_response': ( 'routes/handlers.html#build_items_changed_response',
                                                                                                                                                   'cjm_fasthtml_virtual_collection/routes/handlers.py'),
                                                                 'cjm_fasthtml_virtual_collection.routes.handlers.build_nav_response': ( 'routes/handlers.html#build_nav_response',
                                                                                                                                         'cjm_fasthtml_virtual_collection/routes/handlers.py'),
                                                                 'cjm_fasthtml_virtual_collection.routes.handlers.handle_activate': ( 'routes/handlers.html#handle_activate',
                                                                                                                                      'cjm_fasthtml_virtual_collection/routes/handlers.py'),
                                                                 'cjm_fasthtml_virtual_collection.routes.handlers.handle_focus_row': ( 'routes/handlers.html#handle_focus_row',
                                                                                                                                       'cjm_fasthtml_virtual_collection/routes/handlers.py'),
                                                                 'cjm_fasthtml_virtual_collection.routes.handlers.handle_navigate': ( 'routes/handlers.html#handle_navigate',
                                                                                                                                      'cjm_fasthtml_virtual_collection/routes/handlers.py'),
                                                                 'cjm_fasthtml_virtual_collection.routes.handlers.handle_navigate_to_index': ( 'routes/handlers.html#handle_navigate_to_index',
                                                                                                                                               'cjm_fasthtml_virtual_collection/routes/handlers.py'),
                                                                 'cjm_fasthtml_virtual_collection.routes.handlers.handle_sort': ( 'routes/handlers.html#handle_sort',
                                                                                                                                  'cjm_fasthtml_virtual_collection/routes/handlers.py'),
                                                                 'cjm_fasthtml_virtual_collection.routes.handlers.handle_update_viewport': ( 'routes/handlers.html#handle_update_viewport',
                                                                                                                                             'cjm_fasthtml_virtual_collection/routes/handlers.py')},
            'cjm_fasthtml_virtual_collection.routes.router': { 'cjm_fasthtml_virtual_collection.routes.router.init_virtual_collection_router': ( 'routes/router.html#init_virtual_collection_router',
                                                                                                                                                 'cjm_fasthtml_virtual_collection/routes/router.py')}}}
